@@ -1,7 +1,7 @@
 #include "v4l.h"
 #include <libgnomevfs/gnome-vfs.h>
 
-int add_rgb_text (char *, int, int, char *, char *, gboolean, gboolean);
+int add_rgb_text (guchar *, int, int, char *, char *, gboolean, gboolean);
 void remote_save (cam *);
 void save_thread (cam *);
 int local_save (cam *);
