@@ -1,4 +1,5 @@
 #define PATH "/apps/camorama/preferences"
+#define KEY_DEVICE PATH "/device"
 #define KEY1 "/apps/camorama/preferences/save_dir"
 #define KEY2 "/apps/camorama/preferences/save_file"
 #define KEY3 "/apps/camorama/preferences/file_type"
@@ -21,5 +22,4 @@
 #define KEY20 "/apps/camorama/preferences/auto_capture"
 #define KEY21 "/apps/camorama/preferences/auto_capture_interval"
 #define KEY22 "/apps/camorama/preferences/show_adjustments"
-
-
+#define KEY23 "/apps/camorama/preferences/show_effects"
